<?php
namespace app\article\controller;
use think\Request;
use app\common\lib\Htmlp;
use app\common\controller\UserBase;

class ApiUserArticle extends UserBase
{
    protected $beforeActionList = ['start'];
    public function start() {
        $this->itemType = 'article';
        $this->itemName = '内容';
        $this->item = 'Articles';
        $this->itemCategory = 'ArticlesCategory';
        $this->itemContent = 'ArticlesContent';
        $this->itemSearch = 'ArticlesSearch';
        $this->itemSearchRel = 'ArticlesSearchRel';
        $this->itemModelNameSpace = 'app\article\model\Articles';
        $this->itemCategoryModelNameSpace = 'app\article\model\ArticlesCategory';
    }
    
    public function itemAdd()
    {
        $title = Htmlp::htmlp(input('post.title'));
        $content = Htmlp::htmlp(input('post.content'));
        $cid =  Htmlp::htmlp(input('post.cid'));
        $tags =  Htmlp::htmlp(input('post.tags'));
        $img_url =  Htmlp::htmlp(input('post.img_url'));
        $description = Htmlp::htmlp(input('post.description'));
        $keywords = Htmlp::htmlp(input('post.keywords'));
        $cid = $cid ? $cid : 0;
        if (!$title) {
        	return jsonError('请输入标题');
        }
        if (!$content) {
        	return jsonError('请输入内容');
        }
        $userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($cid);
        if (!$userGroupExtendInfo['articlePublish']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        
        $itemInfo = db('Articles')->where('title',$title)->find();
        if ($itemInfo) {
            return jsonError('文章标题已存在');
        }
    	$stopStatus = model('app\setting\model\BadWords')->badWords($title . $content);
    	if ($stopStatus) {
            return jsonError('您提交的内容中含有敏感词，请修改后再提交');
    	}
        $data = [
        	'title' => $title,
        	'uid' => config('userId'),
        	'content' => $content,
        	'cid' => $cid,
        	'tags' => $tags ? $tags : '',
        	'img_url' => $img_url ? $img_url : '',
        	'description' => $description ? $description : '',
        	'keywords' => $keywords ? $keywords : '',
        ];
        if ($userGroupExtendInfo['articlePublishVerify']) {
	        if (db('ArticlesVerify')->where('uid',config('userId'))->where('create_time','>',strtotime(date('Y-m-d')))->count() >= $userGroupExtendInfo['articlePublishNum']) {
	            return jsonError('你发布次数已达到当天限定的次数');
	        }
        	db('ArticlesVerify')->insert(array (
	            'uuid' => uuid(),
	            'cid' => $data['cid'],
	            'uid' => config('userId'),
	            'title' =>  $data['title'],
	            'img_url' => $data['img_url'],
	            'create_time' => time(),
	            'description' => $data['description'],
	            'keywords' => $data['keywords'],
	            'tags' => $data['tags'],
		     	'content' => htmlspecialchars($data['content']),
		      	'type' => '',
	        ));
        	return jsonSuccess('提交成功，正在审核中','verify');
        } else {
	        if (db('Articles')->where('uid',config('userId'))->where('publish_time','>',strtotime(date('Y-m-d')))->count() >= $userGroupExtendInfo['articlePublishNum']) {
	            return jsonError('你发布次数已达到当天限定的次数');
	        }
        	$res = model('app\article\model\Articles')->itemAdd($data);
        	return jsonSuccess('发布成功');
        }
    }
    
	public function itemEdit()
    {
        $uuid = Htmlp::htmlp(input('post.uuid'));
        $title = Htmlp::htmlp(input('post.title'));
        $content = Htmlp::htmlp(input('post.content'));
        $cid =  Htmlp::htmlp(input('post.cid'));
        $tags =  Htmlp::htmlp(input('post.tags'));
        $verifyTags = Htmlp::htmlp(input('post.verifyTags'));
        $img_url =  Htmlp::htmlp(input('post.img_url'));
        $description = Htmlp::htmlp(input('post.description'));
        $keywords = Htmlp::htmlp(input('post.keywords'));
        $editType = input('post.editType');
        
        if (!$title) {
        	return jsonError('请输入标题');
        }
        if (!$content) {
        	return jsonError('请输入内容');
        }
        
        $userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($cid);
        if (!$userGroupExtendInfo['articlePublishEdit']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        
    	$stopStatus = model('app\setting\model\BadWords')->badWords($title . $content);
    	if ($stopStatus) {
            return jsonError('您提交的内容中含有敏感词，请修改后再提交');
    	}
    	
        $data = [
		  	'uuid' => $uuid,
        	'title' => $title,
        	'content' => $content,
        	'cid' => $cid ? $cid : 0,
        	'tags' => $tags ? $tags : '',
        	'verifyTags' => $verifyTags ? $verifyTags : '',
        	'img_url' => $img_url ? $img_url : '',
        	'description' => $description ? $description : '',
        	'keywords' => $keywords ? $keywords : '',
        ];
        if (!$editType) {
	        $itemInfo = db('Articles')->where('uuid',$uuid)->find();
	        if (!$itemInfo) {
	            return jsonError('文章不存在');
	        }
	        if ($this->userId == $itemInfo['uid'] || $this->isUserAdmin) {
		        if ($userGroupExtendInfo['articlePublishVerify']) {
	        		db('ArticlesVerify')->insert(array (
			            'uuid' => $uuid,
			            'cid' => $data['cid'],
		            	'uid' => $itemInfo['uid'],
			            'title' =>  $data['title'],
			            'img_url' => $data['img_url'],
			            'create_time' => time(),
			            'description' => $data['description'],
			            'keywords' => $data['keywords'],
			            'tags' => $data['tags'],
			            'content' => htmlspecialchars($data['content']),
			            'type' => 'edit',
			        ));
        			return jsonSuccess('提交成功，正在审核中','verify');
		        } else {
	        		$id = model('app\article\model\Articles')->itemEdit($data);
		       		return jsonSuccess('发布成功');
		        }
	        } else {
	        	return jsonError('无权限操作');
	        }
        }
        if ($editType == 'verify') {
        	$itemInfo = db('ArticlesVerify')->where('uuid',$uuid)->find();
	        if (!$itemInfo) {
	            return jsonError('文章不存在');
	        }
	        if ($this->userId == $itemInfo['uid'] || $this->isUserAdmin) {
	    		db('ArticlesVerify')->where('uuid',$uuid)->where('uid',$itemInfo['uid'])->update(array(
		            'cid' => $data['cid'],
		            'title' =>  $data['title'],
		            'img_url' => $data['img_url'],
		            'description' => $data['description'],
		            'keywords' => $data['keywords'],
		            'tags' => $data['verifyTags'],
		            'content' => htmlspecialchars($data['content']),
		        ));
        		return jsonSuccess('提交成功，正在审核中','verify');
	        } else {
	        	return jsonError('无权限操作');
	        }
        }
        
    }
    
    public function itemInfo()
    {
        $uuid = input('post.uuid');
        $editType = input('post.editType');
        if (!$uuid) {
            return jsonError('缺少ID');
        }
        if ($editType == 'verify') {
        	$itemInfo = db('ArticlesVerify')->where('uuid',$uuid)->find();
	        if (!$itemInfo) {
	            return jsonError('文章不存在');
	        }
	        $itemInfo = model('app\article\model\ArticlesVerify')->getItemInfo('',$uuid);
	        $itemInfo = model('app\article\model\ArticlesVerify')->getContentByItemInfo($itemInfo);
        } else {
        	$itemInfo = db('Articles')->where('uuid',$uuid)->find();
	        if (!$itemInfo) {
	            return jsonError('文章不存在');
	        }
	        $itemInfo = model('app\article\model\Articles')->getItemInfo('',$uuid);;
	        $itemInfo = model('app\article\model\Articles')->getContentByItemInfo($itemInfo);
        }
        return jsonSuccess('ok',['itemInfo' => $itemInfo]);
    }

    public function itemDel()
    {
        $uuid = input('post.uuid');
        if (!$uuid) {
            return jsonError('缺少ID');
        }
        $itemInfo = db('Articles')->where('uid',config('userId'))->where('uuid',$uuid)->find();
        if (!$itemInfo) {
            return jsonError('文章不存在');
        }
        
        $userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($itemInfo['cid']);
        if (!$userGroupExtendInfo['articlePublishDel']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        if ($this->userId == $itemInfo['uid']) {
    		db('Articles')->where('uid',config('userId'))->where('uuid',$uuid)->delete();
    	} else {
            return jsonError('无权限操作');
        }
        //日志更新
        $info = $itemInfo['title'];
     	model('app\common\model\Log')->itemAdd($info,config('userId'),'articleDel');
        return jsonSuccess('操作成功');
    }

    public function itemList()
    {
        $page = input('post.page');
        $limit = input('post.limit');
        $orderBy = input('post.orderBy');
        $order = input('post.order');
        
        $page = $page ? $page : 1;
        $limit = $limit ? $limit : 10;
        $orderBy = $orderBy ? $orderBy : 'publish_time';
        $order = $order ? $order : 'desc';
        
     	$itemList = db('Articles')->where('uid',config('userId'))->page($page,$limit)->order($orderBy,$order)->select();
        if ($itemList) {
            foreach($itemList as $k => $v) {
                $itemList[$k] = model('app\\article\\model\\Articles')->getItemInfo($v['id'],null,$v);
            }
        } else {
            $itemList = [];
        }
     	$itemCount = db('Articles')->where('uid',config('userId'))->count();
	    return jsonSuccess('',['itemList' => $itemList,'total' => $itemCount,'page' => $page]);
    }

}