<?php
namespace app\article\controller;

use app\common\lib\Htmlp;
use app\common\controller\UserBase;
class ApiUserArticleComments extends UserBase
{
	protected $beforeActionList = ['start'];
    public function start() {
        $this->itemType = 'article';
        $this->itemName = '内容';
        $this->item = 'Articles';
        $this->itemCategory = 'ArticlesCategory';
        $this->itemContent = 'ArticlesContent';
        $this->itemSearch = 'ArticlesSearch';
        $this->itemSearchRel = 'ArticlesSearchRel';
        $this->itemModelNameSpace = 'app\article\model\Articles';
        $this->itemCategoryModelNameSpace = 'app\article\model\ArticlesCategory';
        $this->itemTagsRelModelNameSpace = 'app\tag\model\TagsRel';
        $this->domain = config('domain');
        $this->settingInfo = config('settingInfo');
        $this->itemSettingInfo = config('articleSettingInfo');
    }
    
    public function itemAdd()
    {
        $itemId = input('post.itemId');
        $content = Htmlp::htmlp(input('post.content'));
        if (!$itemId) {
            return jsonError('缺少参数');
        }
        if (!$content) {
        	return jsonError('请输入内容');
        }
 		
        $itemInfo = db('Articles')->where('uuid',$itemId)->find();
        if (!$itemInfo) {
            return jsonError('文章不存在');
        }
        $userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($itemInfo['cid']);
        if (!$userGroupExtendInfo['articleComment']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        
    	$stopStatus = model('app\setting\model\BadWords')->badWords($content);
    	if ($stopStatus) {
            return jsonError('您提交的内容中含有敏感词，请修改后再提交');
    	}
    	
        if ($userGroupExtendInfo['articleCommentVerify']) {
	        if (db('ArticlesCommentsVerify')->where('uid',config('userId'))->where('create_time','>',strtotime(date('Y-m-d')))->count() >= $userGroupExtendInfo['articleCommentNum']) {
	            return jsonError('你发布次数已达到当天限定的次数');
	        }
	        db('ArticlesCommentsVerify')->insert(array(
	            'id' => uuid(),
	            'pid' => 0,
	            'uid' => $this->userId,
	            'item_id' => $itemInfo['uuid'],
	            'content' => htmlspecialchars($content),
	            'create_time' => time(),
	        ));
        	return jsonSuccess('提交成功，正在审核中');
        } else {
	        if (db('ArticlesComments')->where('uid',config('userId'))->where('create_time','>',strtotime(date('Y-m-d')))->count() >= $userGroupExtendInfo['articleCommentNum']) {
	            return jsonError('你发布次数已达到当天限定的次数');
	        }
	        db('ArticlesComments')->insert(array(
	            'id' => uuid(),
	            'item_id' => $itemInfo['uuid'],
	            'uid' => $this->userId,
	            'content' => htmlspecialchars($content),
	            'create_time' => time(),
	        ));
	        $itemCount = db('ArticlesComments')->where('item_id',$itemId)->count();
	        db('Articles')->where('uuid',$itemId)->update(array('comments_num' => $itemCount));
	        //更新总数量
	        $allTotal = db('ArticlesComments')->count();
	        if (db('BaseKey')->where('key','article_comments_num')->find()) {
	        	db('BaseKey')->where('key','article_comments_num')->update(array('val' => $allTotal));
	        } else {
	        	db('BaseKey')->insert(array('key' => 'article_comments_num','val' => $allTotal));
	        }
	        //更新用户数量
	        db('Users')->where('uid',$this->userId)->update([
	            'article_comments_num' => db('ArticlesComments')->where('uid',$this->userId)->count(),
	        ]);
        }
        return jsonSuccess('发布成功');
    }
    
    public function commentsAdd()
    {
    	$itemId = input('post.itemId');
        $content = Htmlp::htmlp(input('post.content'));
        $isReply = input('post.isReply');
        $replyUid = input('post.replyUid');
        $replyItemId = input('post.replyItemId');
        if (!$itemId) {
            return jsonError('缺少参数');
        }
        if (!$content) {
        	return jsonError('请输入内容');
        }
        $isReply = $isReply ? $isReply : 0;
        $replyUid = $replyUid ? $replyUid : '';
 		
        $commentsInfo = db('ArticlesComments')->where('id',$itemId)->find();
        if (!$commentsInfo) {
        	return jsonError('评论不存在');
        }
        $itemInfo = db('Articles')->where('uuid',$commentsInfo['item_id'])->find();
        if (!$itemInfo) {
            return jsonError('文章不存在');
        }
        $userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($itemInfo['cid']);
        if (!$userGroupExtendInfo['articleComment']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        
    	$stopStatus = model('app\setting\model\BadWords')->badWords($content);
    	if ($stopStatus) {
            return jsonError('您提交的内容中含有敏感词，请修改后再提交');
    	}
        
        if ($userGroupExtendInfo['articleCommentVerify']) {
	       db('ArticlesCommentsVerify')->insert(array(
	            'id' => uuid(),
	            'pid' => 1,
	            'uid' => $this->userId,
	            'item_id' => $itemId,
	            'content' => htmlspecialchars($content),
	            'create_time' => time(),
	            
                'is_reply' => $isReply,
                'reply_uid' => $replyUid,
                'reply_item_id' => $replyItemId,
	        ));
        	return jsonSuccess('提交成功，正在审核中');
        } else {
	        db('ArticlesCommentsComments')->insert(array(
	            'id' => uuid(),
	            'item_id' => $itemId,
	            'uid' => $this->userId,
	            'content' => htmlspecialchars($content),
	            'create_time' => time(),
                'is_reply' => $isReply,
                'reply_uid' => $replyUid,
                'reply_item_id' => $replyItemId,
	        ));
        }
        return jsonSuccess('回复成功');
    }

    public function itemDel()
    {
        $itemId = input('post.itemId');
        $commnetsId = input('post.commentsId');
        if (!$itemId || !$commnetsId) {
            return jsonError('缺少ID');
        }
        $itemInfo = db('Articles')->where('uuid',$itemId)->find();
        if (!$itemInfo) {
            return jsonError('文章不存在');
        }
    	$userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($itemInfo['cid']);
        if (!$userGroupExtendInfo['articleCommentDel']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        $commentsInfo = db('ArticlesComments')->where('id',$commnetsId)->find();
        if(!$commentsInfo) {
            return jsonError('评论不存在');
        }
        if ($this->userId == $commentsInfo['uid'] || $this->isUserAdmin) {
        	db('ArticlesComments')->where('id',$commentsInfo['id'])->delete();
	        db('Articles')->where('uuid',$itemId)->update([
	            'comments_num' => db('ArticlesComments')->where('item_id',$itemId)->count()
	        ]);
	        //日志更新
	        $info = mb_substr(deleteHtml(htmlspecialchars_decode($commentsInfo['content'])),0,30,'utf-8');
	     	model('app\common\model\Log')->itemAdd($info,config('userId'),'articleCommnetsDel');
        } else {
            return jsonError('无权限操作');
        }
        return jsonSuccess('操作成功');
    }
    
    public function commentDel()
    {
    	$itemId = input('post.itemId');
        $commnetsId = input('post.commentsId');
        if (!$itemId || !$commnetsId) {
            return jsonError('缺少ID');
        }
        $itemInfo = db('Articles')->where('uuid',$itemId)->find();
        if (!$itemInfo) {
            return jsonError('文章不存在');
        }
    	$userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($itemInfo['cid']);
        if (!$userGroupExtendInfo['articleCommentDel']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        $commentsInfo = db('ArticlesCommentsComments')->where('id',$commnetsId)->find();
        if(!$commentsInfo) {
            return jsonError('回复不存在');
        }
        if ($this->userId == $commentsInfo['uid'] || $this->isUserAdmin) {
        	db('ArticlesCommentsComments')->where('id',$commentsInfo['id'])->delete();
        } else {
            return jsonError('无权限操作');
        }
        return jsonSuccess('操作成功');
    }
    
    public function itemInfo()
    {
        $itemId = input('post.itemId');
        $commentsId = input('post.commentsId');
        if (!$itemId || !$commentsId) {
            return jsonError('缺少ID');
        }
        if (!db('Articles')->where('uuid',$itemId)->find()) {
            return jsonError('文章不存在');
        }
        $articlesComments = db('ArticlesComments')->where('id',$commentsId)->find();
        if(!$articlesComments) {
            return jsonError('评论不存在');
        }
        $articlesComments['content'] = htmlspecialchars_decode($articlesComments['content']);
        return jsonSuccess('',$articlesComments);
    }
    
    public function itemList()
    {
        $param['itemId'] = input('post.itemId');
        $param['page'] = input('post.page');
        $param['limit'] = input('post.limit');
        $param['orderBy'] = input('post.orderBy');
        $param['order'] = input('post.order');
        if (!$param['itemId']) {
            return jsonError('缺少参数ID');
        }
        $itemList = model('app\article\model\ArticlesComments')->getItemList($param);
        if ($itemList) {
        	
        }
        $total = model('app\article\model\ArticlesComments')->getCount($param);
        if (!$itemList) {
            $itemList = [];
        }
        return jsonSuccess('ok',['itemList' => $itemList,'total' => $total,'page' => $page]);
    }
    public function itemEdit()
    {
        $itemId = input('post.itemId');
        $commentsId = input('post.commentsId');
        $content = Htmlp::htmlp(input('post.content'));
        if(!$itemId || !$commentsId) {
            return jsonError('缺少ID');
        }
        if(!$content) {
            return jsonError('请输入内容');
        }
        $itemInfo = db('Articles')->where('uuid',$itemId)->find();
        if (!$itemInfo) {
            return jsonError('内容不存在');
        }
    	$userGroupExtendInfo = model('app\\article\\model\\Articles')->getUserGroupExtendData($itemInfo['cid']);
        if (!$userGroupExtendInfo['articleCommentEdit']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        if (!$articleCommentsInfo = db('ArticlesComments')->where('id',$commentsId)->find()){
            return jsonError('评论不存在');
        }
        if ($this->userId == $articleCommentsInfo['uid'] || $this->isUserAdmin) {
            if(db('ArticlesComments')->where('id',$commentsId)->update(['content' => htmlspecialchars($content),'edit_time'=>time()])){
                return jsonSuccess('修改成功');
            }
        } else {
            return jsonError('无权限操作');
        }
    }
   
}