<?php
namespace app\user\controller;
use think\Request;
use think\Session;
use think\Validate;
use think\Cache;
use app\common\lib\Htmlp;
use app\common\controller\UserBase;

class ApiUserUser extends UserBase
{
    protected $beforeActionList = ['start'];
    public function start() {
        $this->item = 'Users';
        $this->itemType = 'user';
        $this->itemName = '用户';
        $this->itemContent = 'UsersContent';
        $this->itemCategory = 'UsersGroup';
        $this->itemModelNameSpace = 'app\user\model\Users';
        $this->itemCategoryModelNameSpace = 'app\user\model\UsersGroup';
        $this->categoryListData = config('userCategoryListData');
        $this->categoryAllListData = config('userCategoryListData');
        
        $this->settingInfo = config('settingInfo');
    }
    
    
    public function getUserFollow()
    {
        $uid = input('post.uid');
        $userId = config('userId');
        $fansInfo = db('UsersFans')->where('uid_from',$userId)->where('uid_to',$uid)->find();
        return jsonSuccess('',$fansInfo);
    }
    public function userFollow()
    {
        $uid = input('post.uid');
        if (!$uid) {
        	return jsonError('缺少请求参数');
        }
        $userId = config('userId');
        if ($userId == $uid) {
        	return jsonError('不允许关注自己');
        }
        db('UsersFans')->where('uid_from',$userId)->where('uid_to',$uid)->delete();
        db('UsersFans')->insert(array('uid_from' => $userId, 'uid_to' => $uid, 'add_time' => time()));
        
        $followNum = db('UsersFans')->where('uid_from',$userId)->count();
        db('Users')->where('uid',$userId)->update(array('follow_num' => $followNum));
        $fansNum = db('UsersFans')->where('uid_to',$uid)->count();
        db('Users')->where('uid',$uid)->update(array('fans_num' => $fansNum));
        return jsonSuccess('关注成功');
    }
    
    public function userCancelFollow()
    {
        $uid = input('post.uid');
        if (!$uid) {
        	return jsonError('缺少请求参数');
        }
        $userId = config('userId');
        db('UsersFans')->where('uid_from',$userId)->where('uid_to',$uid)->delete();
        
        $followNum = db('UsersFans')->where('uid_from',$userId)->count();
        db('Users')->where('uid',$userId)->update(array('follow_num' => $followNum));
        $fansNum = db('UsersFans')->where('uid_to',$uid)->count();
        db('Users')->where('uid',$uid)->update(array('fans_num' => $fansNum));
        return jsonSuccess('关注成功');
    }
    
    public function getUserInfo()
    {
        $itemInfo = model($this->itemModelNameSpace)->getItemInfo($this->userId);
        return jsonSuccess('修改成功',$itemInfo);
    }
    public function userEdit(Request $request)
    {
        $nickname = Htmlp::htmlp(trim(input('post.nickname')," \t\n\r\0\x0B"));
        $qq = Htmlp::htmlp(trim(input('post.qq')," \t\n\r\0\x0B"));
        $sex = Htmlp::htmlp(trim(input('post.sex')," \t\n\r\0\x0B"));
        $signature = Htmlp::htmlp(trim(input('post.signature')," \t\n\r\0\x0B"));
        if (!preg_match('/^[\x{4e00}-\x{9fa5}_a-zA-Z0-9]+$/u', $nickname)) {
            return jsonError('昵称仅允许汉字、字母、数字组合');
        }
        if ($nickname != htmlspecialchars($nickname)) {
            return jsonError('昵称含有非法字符');
        }
        if ($signature != htmlspecialchars($signature)) {
            return jsonError('签名含有非法字符');
        }
        if (!$userInfo = db('Users')->where('uid',$this->userId)->find()){
            return jsonError('用户不存在');
        }
        if (!$sex) {
            $sex = 1;
        }
        $data['nickname'] = $nickname;
     	$data['uid'] = $this->userId;
        $data['qq'] = $qq;
        $data['sex'] = $sex;
        $data['signature'] = htmlspecialchars($signature);
        $usersInfo =  db('Users')->where('uid',$this->userId)->update($data);
        return jsonSuccess('修改成功');
    }
    
    public function getAvatarList()
    {
        $numArray = ['a','b','c','d','e','f','g','h','i','j','k','m','l','n','o','p','q','r','s','t','u','v','w','x','y','z','0','1','2','3','4','5','6','7','8','9'];
        $keyInfo = config('keyInfo');
        $avatarType = $keyInfo['avatarType'] ? $keyInfo['avatarType'] : 'one';
        for ($i = 0; $i < count($numArray); $i++) {
            $str = $numArray[$i];
        	$urls[] = ['url' => $this->domainStatic . '/avatar/' . $avatarType . '/' . $avatarType . '_' . $str . '.jpg','name' => $str];    
        }
        return jsonSuccess('修改成功',$urls);
    }
    
    public function userAvatarEdit()
    {
        $avatar = Htmlp::htmlp(input('post.avatar'));
        if(!$avatar){
            return jsonError('缺少参数');
        }
        $userGroupExtendInfo = model('app\\user\\model\\Users')->getUserGroupExtendData();
        if (!$userGroupExtendInfo['avatarUpload']) {
        	return jsonError('你当前所在的分组无此权限');
        }
        $usersInfo = db('Users')->where('uid',$this->userId)->update(array(
            'avatar' => $avatar
        ));
        return jsonSuccess('操作成功');
    }
    
    public function userPasswordEdit()
    {
        $uid = $this->userId;
        $oldPassword = Htmlp::htmlp(input('post.oldPassword'));
        $newPassword = Htmlp::htmlp(input('post.newPassword'));
        $rpassword = Htmlp::htmlp(input('post.rpassword'));
        if(!$oldPassword){
            return jsonError('请输入原来密码');
        }
        if(!$newPassword){
             return jsonError('请输入新密码');
        }
        if (strlen($oldPassword) != 32){
             return jsonError('密码长度不符合规则');
        }
        if (strlen($newPassword) != 32){
             return jsonError('密码长度不符合规则');
        }
        if (strlen($rpassword) != 32){
             return jsonError('密码长度不符合规则');
        }
        if ($oldPassword == $newPassword) {
            return jsonError('新密码不能与旧密码重复');
        }
        if($rpassword != $newPassword){
            return jsonError('两次输入的密码不一样');
        }
        $userPasswordInfo = db('Users')->where('uid',$this->userId)->find();
        $oldpassword = create_md5($oldPassword,$userPasswordInfo['salt']);
        if($oldpassword != $userPasswordInfo['password']) {
             return jsonError('旧密码错误，请重新输入');
        }
        $data['salt'] = create_salt(8);
        $data['password'] = create_md5($newPassword,$data['salt']);
        $usersInfo = db('Users')->where('uid',$uid)->update($data);
        $userToken = cookie('userToken');
        db('UsersToken')->where('token',$userToken)->delete();
        model('app\common\model\Log')->itemAdd('修改密码，用户IP：' . Request::instance()->ip(),config('userId'),'login');
        return  jsonSuccess('修改成功','','/login/');
    }

    public function loginOut()
    {
        $userToken = cookie('userToken');
        db('UsersToken')->where('token',$userToken)->delete();
        model('app\common\model\Log')->itemAdd('退出成功，退出IP：' . Request::instance()->ip(),config('userId'),'login');
        return jsonSuccess('退出成功');
    }
    
}