<?php
namespace app\user\model;
use think\Cache;
use think\Request;
use think\Validate;
use app\common\lib\Paginationm;
use think\Db;
use think\Controller;

class UsersCheck extends Controller
{
    public function checkUserName($username)
    {
        if (!isset($username) || !$username) {
            return ['code' => -1,'msg' => '用户名不能为空'];
        }
        if (strlen($username) > 24 || strlen($username) < 2) {
            return ['code' => -1,'msg' => '用户名长度不合法'];
        }
        if (!preg_match('/^[\x{4e00}-\x{9fa5}_a-zA-Z0-9]+$/u', $username)) {
            return ['code' => -1,'msg' => '仅允许汉字、字母、数字组合'];
        }
        if ($username != htmlspecialchars($username)) {
            return ['code' => -1,'msg' => '用户名含有非法字符'];
        }
        return ['code' => 1];
	}
	
    public function checkEmail($email)
    {
        if (!isset($email) || !$email) {
            return ['code' => -1,'msg' => '邮箱不能为空'];
        }
		if(!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            return ['code' => -1,'msg' => '邮箱格式错误'];
		}
        return ['code' => 1];
	}

    public function checkPassword($password)
    {
        if (!isset($password) || !$password) {
            return ['code' => -1,'msg' => '密码不能为空'];
        }
        if ($rpassword == 'd41d8cd98f00b204e9800998ecf8427e') {
            return ['code' => -1,'msg' => '密码不能为空'];
        }
        return ['code' => 1];
	}
	
    public function checkToken($token)
    {
        if (!isset($token) || !$token) {
            return ['code' => -1,'msg' => 'TOKEN不能为空'];
        }
       	$data = [
            '__token__' => $token,
        ];
        $validate = new Validate([ 
            '__token__' =>'require|token',
        ]);
        if (!$validate->check($data)) {
            return ['code' => -1,'msg' => $validate->getError()];
        }
        return ['code' => 1];
	}
    
    public function checkMobile($mobile)
    {
        if (!isset($mobile) || !$mobile) {
            return ['code' => -1,'msg' => '手机号码不能为空'];
        }
        if (!preg_match("/^1[3456789]\d{9}$/", $mobile)) {
            return ['code' => -1,'msg' => '手机号码格式错误'];
        }
        return ['code' => 1];
	}
	
    public function checkLoginIp()
    {
        $ip = Request::instance()->ip();
        $num = cache('user_error_num_' . $ip . '_' . $userInfo['uid']);
        $time = cache('user_error_time_' . $ip . '_' .$userInfo['uid']);
        if ($num > 30) {
            if ($time > time() - 1800) {
                model('app\common\model\Log')->itemAdd('登录次数过多，登录IP：' . Request::instance()->ip(),$userInfo['uid'],'login');
            	return ['code' => -1,'msg' => '登录次数过多，请稍后再试'];
            }
        }
        return ['code' => 1];
	}
	
	public function updateLoginIp($userInfo)
	{
        $ip = Request::instance()->ip();
		$num = cache('user_error_num_' . $userInfo['uid']);
        if (!$num) {
            $num = 0;
        }
        $num = $num + 1;
        cache('user_error_num_' . $ip . '_' . $userInfo['uid'],$num);
        cache('user_error_time_' . $ip . '_' . $userInfo['uid'],time());
        return ['code' => 1];
	}
	
    public function checkRegIp()
    {
        $ip = Request::instance()->ip();
        $num = cache('user_reg_num_' . $ip);
        $time = cache('user_reg_time_' . $ip);
        if ($num > 10) {
            if ($time > time() - 1800) {
                model('app\common\model\Log')->itemAdd('注册次数过多，注册IP：' . Request::instance()->ip(),'','reg');
            	return ['code' => -1,'msg' => '注册次数过多，请稍后再试'];
            }
        }
        return ['code' => 1];
	}
	
    public function updateRegIp()
    {
        $ip = Request::instance()->ip();
        $num = cache('user_reg_num_' . $ip);
        if (!$num) {
            $num = 0;
        }
        $num = $num + 1;
        cache('user_reg_num_' . $ip,$num);
        cache('user_reg_time_' . $ip,time());
        return ['code' => 1];
	}
	
}